@@ -1,10 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+hurriyetemlak_icon= Icon(
     title="Hurriyetemlak",
     slug="hurriyetemlak",
     hex="E02826",
     source="https://ilan.hurriyetemlak.com/emlak-ilani-yayinlama-kurallari",
-    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Hurriyetemlak icon</title><path d="M24 16.085L11.994 4.091 0 16.097l3.817 3.812 8.182-8.189 8.189 8.182z"/></svg>""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Hurriyetemlak</title><path d="M24 16.085L11.994 4.091 0 16.097l3.817 3.812 8.182-8.189 8.189 8.182z"/></svg>""",
     guidelines=None,
     license=None,
 )
