@@ -1,10 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+nintendo_icon= Icon(
     title="Nintendo",
     slug="nintendo",
     hex="8F8F8F",
     source="https://en.wikipedia.org/wiki/Nintendo#/media/File:Nintendo.svg",
-    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Nintendo icon</title><path d="M0 .6h7.1l9.85 15.9V.6H24v22.8h-7.04L7.06 7.5v15.9H0V.6"/></svg>""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Nintendo</title><path d="M0 .6h7.1l9.85 15.9V.6H24v22.8h-7.04L7.06 7.5v15.9H0V.6"/></svg>""",
     guidelines=None,
     license=None,
 )
