@@ -3,8 +3,8 @@ sketch_icon= Icon(
     title="Sketch",
     slug="sketch",
     hex="F7B500",
-    source="https://www.sketch.com/press/",
+    source="https://www.sketch.com/about-us/#press",
     svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Sketch</title><path d="M12 1.25l6.75 6.637V2L12 1.25zm0 0l-6.05 7h12.1l-6.05-7zm0 0L5.25 2v5.887L12 1.25zM5.25 2L0 9l4.416-.68L5.25 2zM0 9l11.959 13.703.008-.014L4.443 9H0zm18.75-7l.834 6.32L24 9l-5.25-7zM24 9h-4.506l-7.523 13.69.029.06L24 9zM12 22.75l-.031-.057-.008.012.039.045zM5.436 9l6.533 13.686L18.564 9H5.436Z"/></svg>""",
-    guidelines=None,
+    guidelines='https://www.sketch.com/about-us/#press',
     license=None,
 )
