@@ -1,10 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+vercel_icon= Icon(
     title="Vercel",
     slug="vercel",
     hex="000000",
     source="https://vercel.com/design",
-    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vercel icon</title><path d="M24 22.525H0l12-21.05 12 21.05z"/></svg>""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vercel</title><path d="M24 22.525H0l12-21.05 12 21.05z"/></svg>""",
     guidelines=None,
     license=None,
 )
